Credits
-------

``ramlfications`` is written and maintained by `Lynn Root`_ and thanks various
contributors:

- `Hynek Schlawack <https://github.com/hynek>`_
- `Matt Montag <https://github.com/mmontag>`_


.. _`Lynn Root`: https://github.com/econchick
